@@ -149,7 +149,7 @@ class BinaryTransformer(BaseEstimator, TransformerMixin):
     Converts binary categoricals to bools.
 
     Args:
-        nan_unknowns: replaces unknown category with nan.
+        nan_unknowns: replaces unknown category with nan if True, otherwise zero.
     """
     def __init__(self, nan_unknowns = True):
         if not isinstance(nan_unknowns, bool):
@@ -237,6 +237,75 @@ class OrdinalEncoder(BaseEstimator, TransformerMixin):
         
         return pd.DataFrame(output, index = index, columns = columns)
 
+class OneHotEncoder(BaseEstimator, TransformerMixin):
+    """
+    Converts categoricals to one-hot encoding.
+
+    Args:
+        nan_unknowns: replaces unknown category with nan if True, otherwise zero.
+        nan_missing: missing values are nan if True, otherwise zero.
+    """
+    def __init__(self, nan_unknowns = False, nan_missing = False):
+        if not isinstance(nan_unknowns, bool):
+            raise TypeError('nan_unknowns must be bool')
+        self.nan_unknowns = nan_unknowns
+
+        if not isinstance(nan_missing, bool):
+            raise TypeError('nan_missing must be bool')
+        self.nan_missing = nan_missing
+
+
+    def fit(self, X, y = None):
+        """
+        Fits transformer to X.
+
+        Args:
+            X: DataFrame.
+            y: optional.
+
+        Returns:
+            self.
+        """
+        self.categories = dict()
+        for col, s in X.items():
+            self.categories[col] = set(s.dropna().unique())
+        return self
+
+    def transform(self, X):
+        """
+        Ordinal encodes and replaces missing and unknowns with nan.
+
+        Args:
+            X: DataFrame.
+
+        Returns:
+            DataFrame.
+        """
+        index = X.index
+        columns = X.columns
+        X = X.to_numpy()
+        n = X.shape[0]
+        
+        output = []
+        output_columns = []
+        for i, col in enumerate(columns):
+            categories = self.categories[col]
+            Z = np.zeros((n, len(categories)))
+            for j, cat in enumerate(categories):
+                output_columns.append(f'{col}_{j}')
+                idx = X[:,i] == cat
+                Z[idx,j] = 1
+
+            if self.nan_unknowns:
+                Z[~(Z==1).any(axis=1),:] = np.nan
+
+            if self.nan_missing:
+                Z[pd.isnull(X[:,i]),:] = np.nan
+
+            output.append(Z)
+
+        return pd.DataFrame(np.concatenate(output, axis=1), index = index, columns = output_columns)
+
 class ColumnTransformer(BaseEstimator, TransformerMixin):
     """ColumnTransformer specifically for DataFrame.
 
